summaryrefslogtreecommitdiff
path: root/include/toolkit/helper
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-23 09:07:12 +0200
committerNoel Grandin <noel@peralex.com>2015-10-23 10:48:50 +0200
commitc06e2fcc2c03c4b6353bd9a1e282c36de872d777 (patch)
tree69cdc7e4bf9d658b108d2a71a8d9ed41c518ed0d /include/toolkit/helper
parenta1ff0745cc4f78777e8dba1e7bb52d18386d7394 (diff)
com::sun::star->css in include/sot to include/typelib
Change-Id: I9cd92b53370a6b6018d2f7c648890f9c014a27de
Diffstat (limited to 'include/toolkit/helper')
-rw-r--r--include/toolkit/helper/accessiblefactory.hxx24
-rw-r--r--include/toolkit/helper/convert.hxx18
-rw-r--r--include/toolkit/helper/emptyfontdescriptor.hxx8
-rw-r--r--include/toolkit/helper/formpdfexport.hxx2
-rw-r--r--include/toolkit/helper/listenermultiplexer.hxx158
-rw-r--r--include/toolkit/helper/macros.hxx50
-rw-r--r--include/toolkit/helper/property.hxx20
-rw-r--r--include/toolkit/helper/vclunohelper.hxx60
8 files changed, 170 insertions, 170 deletions
diff --git a/include/toolkit/helper/accessiblefactory.hxx b/include/toolkit/helper/accessiblefactory.hxx
index fc99828e2aa6..95255e7a5db8 100644
--- a/include/toolkit/helper/accessiblefactory.hxx
+++ b/include/toolkit/helper/accessiblefactory.hxx
@@ -63,62 +63,62 @@ namespace toolkit
public:
/** creates an accessible context for a button window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXButton* _pXWindow ) = 0;
/** creates an accessible context for a checkbox window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXCheckBox* _pXWindow ) = 0;
/** creates an accessible context for a radio button window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXRadioButton* _pXWindow ) = 0;
/** creates an accessible context for a listbox window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXListBox* _pXWindow ) = 0;
/** creates an accessible context for a fixed hyperlink window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXFixedHyperlink* _pXWindow ) = 0;
/** creates an accessible context for a fixed text window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXFixedText* _pXWindow ) = 0;
/** creates an accessible context for a scrollbar window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXScrollBar* _pXWindow ) = 0;
/** creates an accessible context for a edit window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXEdit* _pXWindow ) = 0;
/** creates an accessible context for a combo box window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXComboBox* _pXWindow ) = 0;
/** creates an accessible context for a toolbox window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXToolBox* _pXWindow ) = 0;
/** creates an accessible context for a generic window
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext >
createAccessibleContext( VCLXWindow* _pXWindow ) = 0;
/** creates an accessible component for the given menu
*/
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible >
+ virtual css::uno::Reference< css::accessibility::XAccessible >
createAccessible( Menu* _pMenu, bool _bIsMenuBar ) = 0;
protected:
diff --git a/include/toolkit/helper/convert.hxx b/include/toolkit/helper/convert.hxx
index 8040c8d0e91d..a189f8562519 100644
--- a/include/toolkit/helper/convert.hxx
+++ b/include/toolkit/helper/convert.hxx
@@ -26,32 +26,32 @@
#include <tools/gen.hxx>
-inline ::com::sun::star::awt::Size AWTSize( const Size& rVCLSize )
+inline css::awt::Size AWTSize( const Size& rVCLSize )
{
- return ::com::sun::star::awt::Size( rVCLSize.Width(), rVCLSize.Height() );
+ return css::awt::Size( rVCLSize.Width(), rVCLSize.Height() );
}
-inline ::Size VCLSize( const ::com::sun::star::awt::Size& rAWTSize )
+inline ::Size VCLSize( const css::awt::Size& rAWTSize )
{
return ::Size( rAWTSize.Width, rAWTSize.Height );
}
-inline ::com::sun::star::awt::Point AWTPoint( const ::Point& rVCLPoint )
+inline css::awt::Point AWTPoint( const ::Point& rVCLPoint )
{
- return ::com::sun::star::awt::Point( rVCLPoint.X(), rVCLPoint.Y() );
+ return css::awt::Point( rVCLPoint.X(), rVCLPoint.Y() );
}
-inline ::Point VCLPoint( const ::com::sun::star::awt::Point& rAWTPoint )
+inline ::Point VCLPoint( const css::awt::Point& rAWTPoint )
{
return ::Point( rAWTPoint.X, rAWTPoint.Y );
}
-inline ::com::sun::star::awt::Rectangle AWTRectangle( const ::Rectangle& rVCLRect )
+inline css::awt::Rectangle AWTRectangle( const ::Rectangle& rVCLRect )
{
- return ::com::sun::star::awt::Rectangle( rVCLRect.Left(), rVCLRect.Top(), rVCLRect.GetWidth(), rVCLRect.GetHeight() );
+ return css::awt::Rectangle( rVCLRect.Left(), rVCLRect.Top(), rVCLRect.GetWidth(), rVCLRect.GetHeight() );
}
-inline ::Rectangle VCLRectangle( const ::com::sun::star::awt::Rectangle& rAWTRect )
+inline ::Rectangle VCLRectangle( const css::awt::Rectangle& rAWTRect )
{
return ::Rectangle( ::Point( rAWTRect.X, rAWTRect.Y ), ::Size( rAWTRect.Width, rAWTRect.Height ) );
}
diff --git a/include/toolkit/helper/emptyfontdescriptor.hxx b/include/toolkit/helper/emptyfontdescriptor.hxx
index d37a85e3ac35..96d5ab54a426 100644
--- a/include/toolkit/helper/emptyfontdescriptor.hxx
+++ b/include/toolkit/helper/emptyfontdescriptor.hxx
@@ -28,16 +28,16 @@
// class EmptyFontDescriptor
-class EmptyFontDescriptor : public ::com::sun::star::awt::FontDescriptor
+class EmptyFontDescriptor : public css::awt::FontDescriptor
{
public:
EmptyFontDescriptor()
{
// Not all enums are initialized correctly in FontDescriptor-CTOR because
// they are set to the first enum value, this is not always the default value.
- Slant = ::com::sun::star::awt::FontSlant_DONTKNOW;
- Underline = ::com::sun::star::awt::FontUnderline::DONTKNOW;
- Strikeout = ::com::sun::star::awt::FontStrikeout::DONTKNOW;
+ Slant = css::awt::FontSlant_DONTKNOW;
+ Underline = css::awt::FontUnderline::DONTKNOW;
+ Strikeout = css::awt::FontStrikeout::DONTKNOW;
}
};
diff --git a/include/toolkit/helper/formpdfexport.hxx b/include/toolkit/helper/formpdfexport.hxx
index 569372f9e3d7..39df68cdf445 100644
--- a/include/toolkit/helper/formpdfexport.hxx
+++ b/include/toolkit/helper/formpdfexport.hxx
@@ -41,7 +41,7 @@ namespace toolkitform
/** creates a PDF compatible control descriptor for the given control
*/
std::unique_ptr<vcl::PDFWriter::AnyWidget> TOOLKIT_DLLPUBLIC describePDFControl(
- const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XControl >& _rxControl,
+ const css::uno::Reference< css::awt::XControl >& _rxControl,
vcl::PDFExtOutDevData& i_pdfExportData
);
diff --git a/include/toolkit/helper/listenermultiplexer.hxx b/include/toolkit/helper/listenermultiplexer.hxx
index b6823dd59219..49dab94db067 100644
--- a/include/toolkit/helper/listenermultiplexer.hxx
+++ b/include/toolkit/helper/listenermultiplexer.hxx
@@ -55,7 +55,7 @@
class TOOLKIT_DLLPUBLIC ListenerMultiplexerBase : public MutexHelper,
public ::cppu::OInterfaceContainerHelper,
- public ::com::sun::star::uno::XInterface
+ public css::uno::XInterface
{
private:
::cppu::OWeakObject& mrContext;
@@ -67,8 +67,8 @@ public:
ListenerMultiplexerBase( ::cppu::OWeakObject& rSource );
virtual ~ListenerMultiplexerBase();
- // ::com::sun::star::uno::XInterface
- ::com::sun::star::uno::Any SAL_CALL queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+ // css::uno::XInterface
+ css::uno::Any SAL_CALL queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception) override;
void SAL_CALL acquire() throw() override { mrContext.acquire(); }
void SAL_CALL release() throw() override { mrContext.release(); }
};
@@ -77,26 +77,26 @@ public:
// class EventListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START( EventListenerMultiplexer, ::com::sun::star::lang::XEventListener )
+DECL_LISTENERMULTIPLEXER_START( EventListenerMultiplexer, css::lang::XEventListener )
DECL_LISTENERMULTIPLEXER_END
// class FocusListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( FocusListenerMultiplexer, ::com::sun::star::awt::XFocusListener )
- void SAL_CALL focusGained( const ::com::sun::star::awt::FocusEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL focusLost( const ::com::sun::star::awt::FocusEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( FocusListenerMultiplexer, css::awt::XFocusListener )
+ void SAL_CALL focusGained( const css::awt::FocusEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL focusLost( const css::awt::FocusEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class WindowListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( WindowListenerMultiplexer, ::com::sun::star::awt::XWindowListener )
- void SAL_CALL windowResized( const ::com::sun::star::awt::WindowEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowMoved( const ::com::sun::star::awt::WindowEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowShown( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowHidden( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( WindowListenerMultiplexer, css::awt::XWindowListener )
+ void SAL_CALL windowResized( const css::awt::WindowEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowMoved( const css::awt::WindowEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowShown( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowHidden( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
@@ -104,163 +104,163 @@ DECL_LISTENERMULTIPLEXER_END
// class VclContainerListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START( VclContainerListenerMultiplexer, ::com::sun::star::awt::XVclContainerListener )
- void SAL_CALL windowAdded( const ::com::sun::star::awt::VclContainerEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowRemoved( const ::com::sun::star::awt::VclContainerEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START( VclContainerListenerMultiplexer, css::awt::XVclContainerListener )
+ void SAL_CALL windowAdded( const css::awt::VclContainerEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowRemoved( const css::awt::VclContainerEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class KeyListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( KeyListenerMultiplexer, ::com::sun::star::awt::XKeyListener )
- void SAL_CALL keyPressed( const ::com::sun::star::awt::KeyEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL keyReleased( const ::com::sun::star::awt::KeyEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( KeyListenerMultiplexer, css::awt::XKeyListener )
+ void SAL_CALL keyPressed( const css::awt::KeyEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL keyReleased( const css::awt::KeyEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class MouseListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( MouseListenerMultiplexer, ::com::sun::star::awt::XMouseListener )
- void SAL_CALL mousePressed( const ::com::sun::star::awt::MouseEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL mouseReleased( const ::com::sun::star::awt::MouseEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL mouseEntered( const ::com::sun::star::awt::MouseEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL mouseExited( const ::com::sun::star::awt::MouseEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( MouseListenerMultiplexer, css::awt::XMouseListener )
+ void SAL_CALL mousePressed( const css::awt::MouseEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL mouseReleased( const css::awt::MouseEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL mouseEntered( const css::awt::MouseEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL mouseExited( const css::awt::MouseEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class MouseMotionListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( MouseMotionListenerMultiplexer, ::com::sun::star::awt::XMouseMotionListener )
- void SAL_CALL mouseDragged( const ::com::sun::star::awt::MouseEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL mouseMoved( const ::com::sun::star::awt::MouseEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( MouseMotionListenerMultiplexer, css::awt::XMouseMotionListener )
+ void SAL_CALL mouseDragged( const css::awt::MouseEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL mouseMoved( const css::awt::MouseEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class PaintListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( PaintListenerMultiplexer, ::com::sun::star::awt::XPaintListener )
- void SAL_CALL windowPaint( const ::com::sun::star::awt::PaintEvent& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( PaintListenerMultiplexer, css::awt::XPaintListener )
+ void SAL_CALL windowPaint( const css::awt::PaintEvent& e ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class TopWindowListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START( TopWindowListenerMultiplexer, ::com::sun::star::awt::XTopWindowListener )
- void SAL_CALL windowOpened( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowClosing( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowClosed( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowMinimized( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowNormalized( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowActivated( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL windowDeactivated( const ::com::sun::star::lang::EventObject& e ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START( TopWindowListenerMultiplexer, css::awt::XTopWindowListener )
+ void SAL_CALL windowOpened( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowClosing( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowClosed( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowMinimized( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowNormalized( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowActivated( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL windowDeactivated( const css::lang::EventObject& e ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class TextListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( TextListenerMultiplexer, ::com::sun::star::awt::XTextListener )
- void SAL_CALL textChanged( const ::com::sun::star::awt::TextEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( TextListenerMultiplexer, css::awt::XTextListener )
+ void SAL_CALL textChanged( const css::awt::TextEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class ActionListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( ActionListenerMultiplexer, ::com::sun::star::awt::XActionListener )
- void SAL_CALL actionPerformed( const ::com::sun::star::awt::ActionEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( ActionListenerMultiplexer, css::awt::XActionListener )
+ void SAL_CALL actionPerformed( const css::awt::ActionEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class ItemListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( ItemListenerMultiplexer, ::com::sun::star::awt::XItemListener )
- void SAL_CALL itemStateChanged( const ::com::sun::star::awt::ItemEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( ItemListenerMultiplexer, css::awt::XItemListener )
+ void SAL_CALL itemStateChanged( const css::awt::ItemEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class TabListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( TabListenerMultiplexer, ::com::sun::star::awt::XTabListener )
- void SAL_CALL inserted( ::sal_Int32 ID ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL removed( ::sal_Int32 ID ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL changed( ::sal_Int32 ID, const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& Properties ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL activated( ::sal_Int32 ID ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL deactivated( ::sal_Int32 ID ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( TabListenerMultiplexer, css::awt::XTabListener )
+ void SAL_CALL inserted( ::sal_Int32 ID ) throw (css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL removed( ::sal_Int32 ID ) throw (css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL changed( ::sal_Int32 ID, const css::uno::Sequence< css::beans::NamedValue >& Properties ) throw (css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL activated( ::sal_Int32 ID ) throw (css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL deactivated( ::sal_Int32 ID ) throw (css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class ContainerListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START( ContainerListenerMultiplexer, ::com::sun::star::container::XContainerListener )
- void SAL_CALL elementInserted( const ::com::sun::star::container::ContainerEvent& Event ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL elementRemoved( const ::com::sun::star::container::ContainerEvent& Event ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL elementReplaced( const ::com::sun::star::container::ContainerEvent& Event ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START( ContainerListenerMultiplexer, css::container::XContainerListener )
+ void SAL_CALL elementInserted( const css::container::ContainerEvent& Event ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL elementRemoved( const css::container::ContainerEvent& Event ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL elementReplaced( const css::container::ContainerEvent& Event ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class SpinListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( SpinListenerMultiplexer, ::com::sun::star::awt::XSpinListener )
- void SAL_CALL up( const ::com::sun::star::awt::SpinEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL down( const ::com::sun::star::awt::SpinEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL first( const ::com::sun::star::awt::SpinEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL last( const ::com::sun::star::awt::SpinEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( SpinListenerMultiplexer, css::awt::XSpinListener )
+ void SAL_CALL up( const css::awt::SpinEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL down( const css::awt::SpinEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL first( const css::awt::SpinEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL last( const css::awt::SpinEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class AdjustmentListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START( AdjustmentListenerMultiplexer, ::com::sun::star::awt::XAdjustmentListener )
- void SAL_CALL adjustmentValueChanged( const ::com::sun::star::awt::AdjustmentEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START( AdjustmentListenerMultiplexer, css::awt::XAdjustmentListener )
+ void SAL_CALL adjustmentValueChanged( const css::awt::AdjustmentEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class MenuListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START( MenuListenerMultiplexer, ::com::sun::star::awt::XMenuListener )
- void SAL_CALL itemHighlighted( const ::com::sun::star::awt::MenuEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL itemSelected( const ::com::sun::star::awt::MenuEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL itemActivated( const ::com::sun::star::awt::MenuEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL itemDeactivated( const ::com::sun::star::awt::MenuEvent& rEvent ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START( MenuListenerMultiplexer, css::awt::XMenuListener )
+ void SAL_CALL itemHighlighted( const css::awt::MenuEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL itemSelected( const css::awt::MenuEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL itemActivated( const css::awt::MenuEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL itemDeactivated( const css::awt::MenuEvent& rEvent ) throw(css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class TreeSelectionListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( TreeSelectionListenerMultiplexer, ::com::sun::star::view::XSelectionChangeListener )
- virtual void SAL_CALL selectionChanged( const ::com::sun::star::lang::EventObject& aEvent ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( TreeSelectionListenerMultiplexer, css::view::XSelectionChangeListener )
+ virtual void SAL_CALL selectionChanged( const css::lang::EventObject& aEvent ) throw (css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class TreeExpansionListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( TreeExpansionListenerMultiplexer, ::com::sun::star::awt::tree::XTreeExpansionListener )
- virtual void SAL_CALL requestChildNodes( const ::com::sun::star::awt::tree::TreeExpansionEvent& aEvent ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL treeExpanding( const ::com::sun::star::awt::tree::TreeExpansionEvent& aEvent ) throw (::com::sun::star::awt::tree::ExpandVetoException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL treeCollapsing( const ::com::sun::star::awt::tree::TreeExpansionEvent& aEvent ) throw (::com::sun::star::awt::tree::ExpandVetoException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL treeExpanded( const ::com::sun::star::awt::tree::TreeExpansionEvent& aEvent ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL treeCollapsed( const ::com::sun::star::awt::tree::TreeExpansionEvent& aEvent ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( TreeExpansionListenerMultiplexer, css::awt::tree::XTreeExpansionListener )
+ virtual void SAL_CALL requestChildNodes( const css::awt::tree::TreeExpansionEvent& aEvent ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL treeExpanding( const css::awt::tree::TreeExpansionEvent& aEvent ) throw (css::awt::tree::ExpandVetoException, css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL treeCollapsing( const css::awt::tree::TreeExpansionEvent& aEvent ) throw (css::awt::tree::ExpandVetoException, css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL treeExpanded( const css::awt::tree::TreeExpansionEvent& aEvent ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL treeCollapsed( const css::awt::tree::TreeExpansionEvent& aEvent ) throw (css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class TreeEditListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( TreeEditListenerMultiplexer, ::com::sun::star::awt::tree::XTreeEditListener )
- virtual void SAL_CALL nodeEditing( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::tree::XTreeNode >& Node ) throw (::com::sun::star::uno::RuntimeException,::com::sun::star::util::VetoException, std::exception) override;
- virtual void SAL_CALL nodeEdited( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::tree::XTreeNode >& Node, const OUString& NewText ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( TreeEditListenerMultiplexer, css::awt::tree::XTreeEditListener )
+ virtual void SAL_CALL nodeEditing( const css::uno::Reference< css::awt::tree::XTreeNode >& Node ) throw (css::uno::RuntimeException,css::util::VetoException, std::exception) override;
+ virtual void SAL_CALL nodeEdited( const css::uno::Reference< css::awt::tree::XTreeNode >& Node, const OUString& NewText ) throw (css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class SelectionListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( SelectionListenerMultiplexer, ::com::sun::star::awt::grid::XGridSelectionListener )
- void SAL_CALL selectionChanged( const ::com::sun::star::awt::grid::GridSelectionEvent& aEvent ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( SelectionListenerMultiplexer, css::awt::grid::XGridSelectionListener )
+ void SAL_CALL selectionChanged( const css::awt::grid::GridSelectionEvent& aEvent ) throw (css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
// class TabPageListenerMultiplexer
-DECL_LISTENERMULTIPLEXER_START_DLLPUB( TabPageListenerMultiplexer, ::com::sun::star::awt::tab::XTabPageContainerListener )
- void SAL_CALL tabPageActivated( const ::com::sun::star::awt::tab::TabPageActivatedEvent& aEvent ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+DECL_LISTENERMULTIPLEXER_START_DLLPUB( TabPageListenerMultiplexer, css::awt::tab::XTabPageContainerListener )
+ void SAL_CALL tabPageActivated( const css::awt::tab::TabPageActivatedEvent& aEvent ) throw (css::uno::RuntimeException, std::exception) override;
DECL_LISTENERMULTIPLEXER_END
#endif // INCLUDED_TOOLKIT_HELPER_LISTENERMULTIPLEXER_HXX
diff --git a/include/toolkit/helper/macros.hxx b/include/toolkit/helper/macros.hxx
index 3ffe023fee99..584129131b0f 100644
--- a/include/toolkit/helper/macros.hxx
+++ b/include/toolkit/helper/macros.hxx
@@ -25,7 +25,7 @@
#include <comphelper/servicehelper.hxx>
#define IMPL_XUNOTUNNEL_MINIMAL( ClassName ) \
-sal_Int64 ClassName::getSomething( const ::com::sun::star::uno::Sequence< sal_Int8 >& rIdentifier ) throw(::com::sun::star::uno::RuntimeException, std::exception) \
+sal_Int64 ClassName::getSomething( const css::uno::Sequence< sal_Int8 >& rIdentifier ) throw(css::uno::RuntimeException, std::exception) \
{ \
if( ( rIdentifier.getLength() == 16 ) && ( 0 == memcmp( ClassName::GetUnoTunnelId().getConstArray(), rIdentifier.getConstArray(), 16 ) ) ) \
{ \
@@ -37,28 +37,28 @@ namespace \
{ \
class the##ClassName##UnoTunnelId : public rtl::Static< UnoTunnelIdInit, the##ClassName##UnoTunnelId> {}; \
} \
-const ::com::sun::star::uno::Sequence< sal_Int8 >& ClassName::GetUnoTunnelId() throw() \
+const css::uno::Sequence< sal_Int8 >& ClassName::GetUnoTunnelId() throw() \
{ \
return the##ClassName##UnoTunnelId::get().getSeq(); \
}
#define IMPL_XUNOTUNNEL( ClassName ) \
IMPL_XUNOTUNNEL_MINIMAL( ClassName ) \
-ClassName* ClassName::GetImplementation( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& rxIFace ) \
+ClassName* ClassName::GetImplementation( const css::uno::Reference< css::uno::XInterface >& rxIFace ) \
{ \
- ::com::sun::star::uno::Reference< ::com::sun::star::lang::XUnoTunnel > xUT( rxIFace, ::com::sun::star::uno::UNO_QUERY ); \
+ css::uno::Reference< css::lang::XUnoTunnel > xUT( rxIFace, css::uno::UNO_QUERY ); \
return xUT.is() ? reinterpret_cast<ClassName*>(sal::static_int_cast<sal_IntPtr>(xUT->getSomething( ClassName::GetUnoTunnelId() ))) : NULL; \
}
#define IMPL_IMPLEMENTATION_ID( ClassName ) \
-::com::sun::star::uno::Sequence< sal_Int8 > ClassName::getImplementationId() throw(::com::sun::star::uno::RuntimeException, std::exception) \
+css::uno::Sequence< sal_Int8 > ClassName::getImplementationId() throw(css::uno::RuntimeException, std::exception) \
{ \
return css::uno::Sequence<sal_Int8>(); \
}
#define IMPL_XTYPEPROVIDER_START( ClassName ) \
IMPL_IMPLEMENTATION_ID( ClassName ) \
-::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type > ClassName::getTypes() throw(::com::sun::star::uno::RuntimeException, std::exception) \
+css::uno::Sequence< css::uno::Type > ClassName::getTypes() throw(css::uno::RuntimeException, std::exception) \
{ \
static ::cppu::OTypeCollection* pCollection = NULL; \
if( !pCollection ) \
@@ -86,10 +86,10 @@ class ClassName : public ListenerMultiplexerBase, public InterfaceName \
{ \
public: \
ClassName( ::cppu::OWeakObject& rSource ); \
- ::com::sun::star::uno::Any SAL_CALL queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception) override; \
+ css::uno::Any SAL_CALL queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception) override; \
void SAL_CALL acquire() throw() override; \
void SAL_CALL release() throw() override; \
- void SAL_CALL disposing( const ::com::sun::star::lang::EventObject& Source ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+ void SAL_CALL disposing( const css::lang::EventObject& Source ) throw(css::uno::RuntimeException, std::exception) override;
@@ -98,10 +98,10 @@ class TOOLKIT_DLLPUBLIC ClassName : public ListenerMultiplexerBase, public Inter
{ \
public: \
ClassName( ::cppu::OWeakObject& rSource ); \
- ::com::sun::star::uno::Any SAL_CALL queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception) override; \
+ css::uno::Any SAL_CALL queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception) override; \
void SAL_CALL acquire() throw() override; \
void SAL_CALL release() throw() override; \
- void SAL_CALL disposing( const ::com::sun::star::lang::EventObject& Source ) throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+ void SAL_CALL disposing( const css::lang::EventObject& Source ) throw(css::uno::RuntimeException, std::exception) override;
@@ -117,14 +117,14 @@ ClassName::ClassName( ::cppu::OWeakObject& rSource ) \
} \
void SAL_CALL ClassName::acquire() throw() { ListenerMultiplexerBase::acquire(); } \
void SAL_CALL ClassName::release() throw() { ListenerMultiplexerBase::release(); } \
-::com::sun::star::uno::Any ClassName::queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception) \
+css::uno::Any ClassName::queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception) \
{ \
- ::com::sun::star::uno::Any aRet = ::cppu::queryInterface( rType, \
- (static_cast< ::com::sun::star::lang::XEventListener* >(this)), \
+ css::uno::Any aRet = ::cppu::queryInterface( rType, \
+ (static_cast< css::lang::XEventListener* >(this)), \
(static_cast< InterfaceName* >(this)) ); \
return (aRet.hasValue() ? aRet : ListenerMultiplexerBase::queryInterface( rType )); \
} \
-void ClassName::disposing( const ::com::sun::star::lang::EventObject& ) throw(::com::sun::star::uno::RuntimeException, std::exception) \
+void ClassName::disposing( const css::lang::EventObject& ) throw(css::uno::RuntimeException, std::exception) \
{ \
}
@@ -145,19 +145,19 @@ void ClassName::disposing( const ::com::sun::star::lang::EventObject& ) throw(::
::cppu::OInterfaceIteratorHelper aIt( *this ); \
while( aIt.hasMoreElements() ) \
{ \
- ::com::sun::star::uno::Reference< InterfaceName > xListener( \
+ css::uno::Reference< InterfaceName > xListener( \
static_cast< InterfaceName* >( aIt.next() ) ); \
try \
{ \
xListener->MethodName( aMulti ); \
} \
- catch(const ::com::sun::star::lang::DisposedException& e) \
+ catch(const css::lang::DisposedException& e) \
{ \
OSL_ENSURE( e.Context.is(), "caught DisposedException with empty Context field" ); \
if ( e.Context == xListener || !e.Context.is() ) \
aIt.remove(); \
} \
- catch(const ::com::sun::star::uno::RuntimeException& e) \
+ catch(const css::uno::RuntimeException& e) \
{ \
DISPLAY_EXCEPTION( ClassName, MethodName, e ) \
} \
@@ -171,19 +171,19 @@ void ClassName::disposing( const ::com::sun::star::lang::EventObject& ) throw(::
::cppu::OInterfaceIteratorHelper aIt( *this ); \
while( aIt.hasMoreElements() ) \
{ \
- ::com::sun::star::uno::Reference< InterfaceName > xListener( \
+ css::uno::Reference< InterfaceName > xListener( \
static_cast< InterfaceName* >( aIt.next() ) ); \
try \
{ \
xListener->MethodName( aMulti ); \
} \
- catch(const ::com::sun::star::lang::DisposedException& e) \
+ catch(const css::lang::DisposedException& e) \
{ \
OSL_ENSURE( e.Context.is(), "caught DisposedException with empty Context field" ); \
if ( e.Context == xListener || !e.Context.is() ) \
aIt.remove(); \
} \
- catch(const ::com::sun::star::uno::RuntimeException& e) \
+ catch(const css::uno::RuntimeException& e) \
{ \
DISPLAY_EXCEPTION( ClassName, MethodName, e ) \
} \
@@ -191,18 +191,18 @@ void ClassName::disposing( const ::com::sun::star::lang::EventObject& ) throw(::
}
#define IMPL_LISTENERMULTIPLEXER_LISTENERMETHOD_EXCEPTION( ClassName, InterfaceName, MethodName, EventType, Exception ) \
-void ClassName::MethodName( const EventType& evt ) throw(::com::sun::star::uno::RuntimeException, Exception, std::exception) \
+void ClassName::MethodName( const EventType& evt ) throw(css::uno::RuntimeException, Exception, std::exception) \
IMPL_LISTENERMULTIPLEXER_LISTENERMETHOD_BODY( ClassName, InterfaceName, MethodName, EventType )
#define IMPL_LISTENERMULTIPLEXER_LISTENERMETHOD( ClassName, InterfaceName, MethodName, EventType ) \
-void ClassName::MethodName( const EventType& evt ) throw(::com::sun::star::uno::RuntimeException, std::exception) \
+void ClassName::MethodName( const EventType& evt ) throw(css::uno::RuntimeException, std::exception) \
IMPL_LISTENERMULTIPLEXER_LISTENERMETHOD_BODY( ClassName, InterfaceName, MethodName, EventType )
#define DECLIMPL_SERVICEINFO_DERIVED( ImplName, BaseClass, ServiceName ) \
- OUString SAL_CALL getImplementationName( ) throw(::com::sun::star::uno::RuntimeException, std::exception) override { return OUString("stardiv.Toolkit." #ImplName ); } \
- ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() throw(::com::sun::star::uno::RuntimeException, std::exception) override \
+ OUString SAL_CALL getImplementationName( ) throw(css::uno::RuntimeException, std::exception) override { return OUString("stardiv.Toolkit." #ImplName ); } \
+ css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() throw(css::uno::RuntimeException, std::exception) override \
{ \
- ::com::sun::star::uno::Sequence< OUString > aNames = BaseClass::getSupportedServiceNames( ); \
+ css::uno::Sequence< OUString > aNames = BaseClass::getSupportedServiceNames( ); \
aNames.realloc( aNames.getLength() + 1 ); \
aNames[ aNames.getLength() - 1 ] = ServiceName; \
return aNames; \
diff --git a/include/toolkit/helper/property.hxx b/include/toolkit/helper/property.hxx
index 92f772bf6f19..114795b880f7 100644
--- a/include/toolkit/helper/property.hxx
+++ b/include/toolkit/helper/property.hxx
@@ -43,7 +43,7 @@ namespace uno {
#define BASEPROPERTY_LINECOLOR 5 // sal_Int32
#define BASEPROPERTY_BORDER 6 // sal_Int16
#define BASEPROPERTY_ALIGN 7 // sal_Int16
-#define BASEPROPERTY_FONTDESCRIPTOR 8 // ::com::sun::star::awt::FontDescriptor
+#define BASEPROPERTY_FONTDESCRIPTOR 8 // css::awt::FontDescriptor
#define BASEPROPERTY_DROPDOWN 9 // sal_Bool
#define BASEPROPERTY_MULTILINE 10 // sal_Bool
#define BASEPROPERTY_STRINGITEMLIST 11 // UStringSequence
@@ -65,12 +65,12 @@ namespace uno {
#define BASEPROPERTY_SPIN 27 // sal_Bool
#define BASEPROPERTY_STRICTFORMAT 28 // sal_Bool
#define BASEPROPERTY_DECIMALACCURACY 29 // sal_Int16
-#define BASEPROPERTY_DATE 30 // ::com::sun::star::util::Date
-#define BASEPROPERTY_DATEMIN 31 // ::com::sun::star::util::Date
-#define BASEPROPERTY_DATEMAX 32 // ::com::sun::star::util::Date
-#define BASEPROPERTY_TIME 33 // ::com::sun::star::util::Time
-#define BASEPROPERTY_TIMEMIN 34 // ::com::sun::star::util::Time
-#define BASEPROPERTY_TIMEMAX 35 // ::com::sun::star::util::Time
+#define BASEPROPERTY_DATE 30 // css::util::Date
+#define BASEPROPERTY_DATEMIN 31 // css::util::Date
+#define BASEPROPERTY_DATEMAX 32 // css::util::Date
+#define BASEPROPERTY_TIME 33 // css::util::Time
+#define BASEPROPERTY_TIMEMIN 34 // css::util::Time
+#define BASEPROPERTY_TIMEMAX 35 // css::util::Time
#define BASEPROPERTY_VALUE_INT32 36 // sal_Int32
#define BASEPROPERTY_VALUEMIN_INT32 37 // sal_Int32
#define BASEPROPERTY_VALUEMAX_INT32 38 // sal_Int32
@@ -97,7 +97,7 @@ namespace uno {
#define BASEPROPERTY_AUTOTOGGLE 59 // sal_Bool
//#define BASEPROPERTY_FOCUSSELECTIONHIDE 60 // sal_Bool
#define BASEPROPERTY_FORMATKEY 61 // sal_Bool
-#define BASEPROPERTY_FORMATSSUPPLIER 62 // ::com::sun::star::util::XNumberFormatsSupplier
+#define BASEPROPERTY_FORMATSSUPPLIER 62 // css::util::XNumberFormatsSupplier
#define BASEPROPERTY_EFFECTIVE_VALUE 63 // Any (double or string)
#define BASEPROPERTY_TREATASNUMBER 64 // sal_Bool
#define BASEPROPERTY_EFFECTIVE_DEFAULT 65 // Any (double or string)
@@ -235,12 +235,12 @@ namespace uno {
TOOLKIT_DLLPUBLIC sal_uInt16 GetPropertyId( const OUString& rPropertyName );
-const ::com::sun::star::uno::Type* GetPropertyType( sal_uInt16 nPropertyId );
+const css::uno::Type* GetPropertyType( sal_uInt16 nPropertyId );
TOOLKIT_DLLPUBLIC const OUString& GetPropertyName( sal_uInt16 nPropertyId );
sal_Int16 GetPropertyAttribs( sal_uInt16 nPropertyId );
sal_uInt16 GetPropertyOrderNr( sal_uInt16 nPropertyId );
bool DoesDependOnOthers( sal_uInt16 nPropertyId );
-bool CompareProperties( const ::com::sun::star::uno::Any& r1, const ::com::sun::star::uno::Any& r2 );
+bool CompareProperties( const css::uno::Any& r1, const css::uno::Any& r2 );
diff --git a/include/toolkit/helper/vclunohelper.hxx b/include/toolkit/helper/vclunohelper.hxx
index a03e89655b18..bd02d6a498d0 100644
--- a/include/toolkit/helper/vclunohelper.hxx
+++ b/include/toolkit/helper/vclunohelper.hxx
@@ -73,36 +73,36 @@ class TOOLKIT_DLLPUBLIC VCLUnoHelper
{
public:
// Toolkit
- static ::com::sun::star::uno::Reference< ::com::sun::star::awt::XToolkit> CreateToolkit();
+ static css::uno::Reference< css::awt::XToolkit> CreateToolkit();
// Bitmap
- static BitmapEx GetBitmap( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XBitmap>& rxBitmap );
- static ::com::sun::star::uno::Reference< ::com::sun::star::awt::XBitmap> CreateBitmap( const BitmapEx& rBitmap );
+ static BitmapEx GetBitmap( const css::uno::Reference< css::awt::XBitmap>& rxBitmap );
+ static css::uno::Reference< css::awt::XBitmap> CreateBitmap( const BitmapEx& rBitmap );
// Window
- static VclPtr< vcl::Window > GetWindow( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow>& rxWindow );
- static VclPtr< vcl::Window > GetWindow( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow2>& rxWindow2 );
- static VclPtr< vcl::Window > GetWindow( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer>& rxWindowPeer );
- static ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow> GetInterface( vcl::Window* pWindow );
+ static VclPtr< vcl::Window > GetWindow( const css::uno::Reference< css::awt::XWindow>& rxWindow );
+ static VclPtr< vcl::Window > GetWindow( const css::uno::Reference< css::awt::XWindow2>& rxWindow2 );
+ static VclPtr< vcl::Window > GetWindow( const css::uno::Reference< css::awt::XWindowPeer>& rxWindowPeer );
+ static css::uno::Reference< css::awt::XWindow> GetInterface( vcl::Window* pWindow );
// OutputDevice
- static OutputDevice* GetOutputDevice( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice>& rxDevice );
- static OutputDevice* GetOutputDevice( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XGraphics>& rxGraphics );
+ static OutputDevice* GetOutputDevice( const css::uno::Reference< css::awt::XDevice>& rxDevice );
+ static OutputDevice* GetOutputDevice( const css::uno::Reference< css::awt::XGraphics>& rxGraphics );
// Region
- static vcl::Region GetRegion( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XRegion >& rxRegion );
+ static vcl::Region GetRegion( const css::uno::Reference< css::awt::XRegion >& rxRegion );
// Polygon
- static tools::Polygon CreatePolygon( const ::com::sun::star::uno::Sequence< sal_Int32 >& DataX, const ::com::sun::star::uno::Sequence< sal_Int32 >& DataY );
+ static tools::Polygon CreatePolygon( const css::uno::Sequence< sal_Int32 >& DataX, const css::uno::Sequence< sal_Int32 >& DataY );
- /** convert Font to ::com::sun::star::awt::FontDescriptor
+ /** convert Font to css::awt::FontDescriptor
@param rFont Font to be converted
@return the new FontDescriptor
*/
- static ::com::sun::star::awt::FontDescriptor CreateFontDescriptor( const vcl::Font& rFont );
- static vcl::Font CreateFont( const ::com::sun::star::awt::FontDescriptor& rDescr, const vcl::Font& rInitFont );
- static vcl::Font CreateFont( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XFont >& rxFont );
- static ::com::sun::star::awt::SimpleFontMetric CreateFontMetric( const FontMetric& rFontMetric );
+ static css::awt::FontDescriptor CreateFontDescriptor( const vcl::Font& rFont );
+ static vcl::Font CreateFont( const css::awt::FontDescriptor& rDescr, const vcl::Font& rInitFont );
+ static vcl::Font CreateFont( const css::uno::Reference< css::awt::XFont >& rxFont );
+ static css::awt::SimpleFontMetric CreateFontMetric( const FontMetric& rFontMetric );
static float ConvertFontWidth( FontWidth eWidth );
static FontWidth ConvertFontWidth( float f );
static float ConvertFontWeight( FontWeight eWeight );
@@ -113,7 +113,7 @@ public:
// Rectangle
static bool IsZero(const css::awt::Rectangle& rRect);
- static ::com::sun::star::uno::Reference< ::com::sun::star::awt::XControlContainer> CreateControlContainer( vcl::Window* pWindow );
+ static css::uno::Reference< css::awt::XControlContainer> CreateControlContainer( vcl::Window* pWindow );
// MapUnits
static MapUnit UnoEmbed2VCLMapUnit( sal_Int32 nUnoEmbedMapUnit );
@@ -128,32 +128,32 @@ public:
static sal_Int16 ConvertToMeasurementUnit( FieldUnit _nFieldUnit, sal_Int16 _rFieldToUNOValueFactor );
static FieldUnit ConvertToFieldUnit( sal_Int16 _nMeasurementUnit, sal_Int16& _rFieldToUNOValueFactor );
- static MapUnit /* MapModeUnit */ ConvertToMapModeUnit(sal_Int16 /* com.sun.star.util.MeasureUnit.* */ _nMeasureUnit) throw (::com::sun::star::lang::IllegalArgumentException);
+ static MapUnit /* MapModeUnit */ ConvertToMapModeUnit(sal_Int16 /* com.sun.star.util.MeasureUnit.* */ _nMeasureUnit) throw (css::lang::IllegalArgumentException);
- static ::Size /* VCLSize */ ConvertToVCLSize(::com::sun::star::awt::Size const& _aSize);
- static ::com::sun::star::awt::Size ConvertToAWTSize(::Size /* VCLSize */ const& _aSize);
+ static ::Size /* VCLSize */ ConvertToVCLSize(css::awt::Size const& _aSize);
+ static css::awt::Size ConvertToAWTSize(::Size /* VCLSize */ const& _aSize);
- static ::Point /* VCLPoint */ ConvertToVCLPoint(::com::sun::star::awt::Point const& _aPoint);
- static ::com::sun::star::awt::Point ConvertToAWTPoint(::Point /* VCLPoint */ const& _aPoint);
+ static ::Point /* VCLPoint */ ConvertToVCLPoint(css::awt::Point const& _aPoint);
+ static css::awt::Point ConvertToAWTPoint(::Point /* VCLPoint */ const& _aPoint);
- static ::Rectangle ConvertToVCLRect( ::com::sun::star::awt::Rectangle const & _rRect );
- static ::com::sun::star::awt::Rectangle ConvertToAWTRect( ::Rectangle const & _rRect );
+ static ::Rectangle ConvertToVCLRect( css::awt::Rectangle const & _rRect );
+ static css::awt::Rectangle ConvertToAWTRect( ::Rectangle const & _rRect );
- static ::com::sun::star::awt::MouseEvent
+ static css::awt::MouseEvent
createMouseEvent(
const ::MouseEvent& _rVclEvent,
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxContext
+ const css::uno::Reference< css::uno::XInterface >& _rxContext
);
- static ::MouseEvent createVCLMouseEvent( const ::com::sun::star::awt::MouseEvent& _rAwtEvent );
+ static ::MouseEvent createVCLMouseEvent( const css::awt::MouseEvent& _rAwtEvent );
- static ::com::sun::star::awt::KeyEvent
+ static css::awt::KeyEvent
createKeyEvent(
const ::KeyEvent& _rVclEvent,
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxContext
+ const css::uno::Reference< css::uno::XInterface >& _rxContext
);
- static ::KeyEvent createVCLKeyEvent( const ::com::sun::star::awt::KeyEvent& _rAwtEvent );
+ static ::KeyEvent createVCLKeyEvent( const css::awt::KeyEvent& _rAwtEvent );
};